@@ -44,7 +44,7 @@ def _process_measures_conc(measure_tasks: list[_ProcessTask]) -> dict:
     processed_measures = {}
     task_n = len(measure_tasks)
     for i, task in enumerate(measure_tasks):
-        processed_measures[(task.measure.group_name, task.measure.index)] = _process_task_conc(task, i, task_n)
+        processed_measures[(task.measure.set_id, task.measure.index)] = _process_task_conc(task, i, task_n)
     return processed_measures
 
 
@@ -58,7 +58,7 @@ def _process_measures(measure_tasks: list[_ProcessTask]) -> dict[str, list[Curve
 
 def _create_tasks(frc_sets: Union[list[FRCSet], FRCSet], preprocess=True,
                   extra_processings: Optional[list[MeasureProcessing]] = None,
-                  override_n: int = 0) -> list[_ProcessTask]:
+                  override_n: int = 0, frc1_method: int = 1) -> list[_ProcessTask]:
     if isinstance(frc_sets, FRCSet):
         frc_sets = [frc_sets]
     process_tasks = []
@@ -73,7 +73,7 @@ def _create_tasks(frc_sets: Union[list[FRCSet], FRCSet], preprocess=True,
             if measure.extra_processings is not None:
                 tasks += measure.extra_processings
 
-            override_n_measure = partial(measure_curve, override_n=override_n)
+            override_n_measure = partial(measure_curve, override_n=override_n, frc1_method=frc1_method)
 
             tasks.append(override_n_measure)
             process_tasks.append(_ProcessTask(tasks, measure))
@@ -114,15 +114,15 @@ def group_sets(curves: list[Curve]) -> dict[str, list[Curve]]:
     """ Grouped so all curves per set will be plotted together. """
     group_dict = {}
     for c in curves:
-        if c.measure.group_name not in group_dict:
-            group_dict[c.measure.group_name] = [c]
+        if c.measure.set_id not in group_dict:
+            group_dict[c.measure.set_id] = [c]
         else:
-            group_dict[c.measure.group_name].append(c)
+            group_dict[c.measure.set_id].append(c)
     return group_dict
 
 
 def process_frc(process_name: str, frc_sets: Union[list[FRCSet], FRCSet], preprocess=True, concurrency=False,
-                grouping: str = 'measures', override_n: int = 0,
+                grouping: str = 'measures', override_n: int = 0, frc1_method: int = 1,
                 extra_processings: Optional[list[MeasureProcessing]] = None) -> dict[str, list[Curve]]:
     """
     Process prepared FRCSets and compute curves.
@@ -136,11 +136,12 @@ def process_frc(process_name: str, frc_sets: Union[list[FRCSet], FRCSet], prepro
         FRCMeasurement are grouped together.
     :param int override_n: Override the default number of curves calculated and averaged. Will override even custom-set
         options for *all* curves.
+    :param int frc1_method: Override the 1FRC method used. Defaults to single split and then subtract.
     :param extra_processings: Additional processing functions that are performed after preprocessing and before
         per-measurement extra processings.
     """
     print("Processing FRC sets...")
-    tasks = _create_tasks(frc_sets, preprocess, extra_processings, override_n)
+    tasks = _create_tasks(frc_sets, preprocess, extra_processings, override_n, frc1_method)
     processed_measures = _process_measures_conc(tasks) if concurrency else _process_measures(tasks)
     processed_curves = [curve for curves in processed_measures.values() for curve in curves]
     print(f"Finished processing, returning curves grouped by {grouping}.")
@@ -168,21 +169,25 @@ def preprocess_img(img: np.ndarray) -> np.ndarray:
     return util.apply_tukey(img)
 
 
-def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasurement:
+def measure_curve(measure: FRCMeasurement, override_n: int = 0, frc1_method: int = 1) -> FRCMeasurement:
     """ Compute curves for an FRCMeasurement. """
     img = measure.image
     # Can be None
     img2 = measure.image_2
     img_size = img.shape[0]
-    nm_per_pixel = measure.settings.nm_per_pixel
+    len_per_pixel = measure.settings.len_per_pixel
     # For correct dimensions we use the first curve calculation below
     xs_pix = None
-    xs_nm_freq = None
+    xs_len_freq = None
 
     # Initialize default curve tasks
     if measure.curve_tasks is None:
         if measure.image_2 is None:
-            measure.curve_tasks = [CurveTask(key='curve1')]
+            if frc1_method == 2:
+                method_str = '1FRC2'
+            else:
+                method_str = '1FRC'
+            measure.curve_tasks = [CurveTask(key='curve1', method=method_str)]
         else:
             measure.curve_tasks = [CurveTask(key='curve1', method='2FRC', avg_n=1)]
 
@@ -199,6 +204,10 @@ def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasuremen
         elif curve_task.method == '2FRC':
             def frc_func(img_frc_1, img_frc_2):
                 return frcf.two_frc(img_frc_1, img_frc_2)
+        elif curve_task.method == '1FRC2':
+            # Experimental
+            def frc_func(img_frc, _img2):
+                return frcf.one_frc(img_frc, 2)
         else:
             raise ValueError("Unknown method {}".format(curve_task.method))
 
@@ -206,7 +215,7 @@ def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasuremen
 
         # Only calculate the first time
         xs_pix = np.arange(len(frc_curve)) / img_size if xs_pix is None else xs_pix
-        xs_nm_freq = xs_pix * (1 / nm_per_pixel) if xs_nm_freq is None else xs_nm_freq
+        xs_len_freq = xs_pix * (1 / len_per_pixel) if xs_len_freq is None else xs_len_freq
 
         # Curve averaging
         frc_curves = [frc_curve]
@@ -217,15 +226,19 @@ def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasuremen
 
         frc_curve /= curve_task.avg_n
 
-        label = curve_task.method
+        curve_key = f"{measure.name}"
+
+        if len(measure.curve_tasks) > 1:
+            curve_key += f"-curve {curve_i}"
+        label = curve_key
 
         smooth_desc = ""
         if curve_task.smooth:
-            smooth_desc = " LOESS smoothing (point frac: {}).".format(curve_task.smooth_frac)
+            smooth_desc = " LOESS smoothing (point frac: {}). ".format(curve_task.smooth_frac)
             xs_pix, frc_curve, wout = loess_1d(xs_pix, frc_curve, frac=curve_task.smooth_frac)
 
         frc_res = -1
-        sd_str = " "
+        sd_str = ""
 
         res_sd = 0
         res_y = 0
@@ -233,12 +246,12 @@ def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasuremen
 
         # Try catch-block since it is possible no resolution could be computed
         try:
-            frc_res, res_y, thres = frcf.frc_res(xs_nm_freq, frc_curve, img_size, threshold=curve_task.threshold)
+            frc_res, res_y, thres = frcf.frc_res(xs_len_freq, frc_curve, img_size, threshold=curve_task.threshold)
             thres_curve = thres(xs_pix)
             frc_res_list = []
             for res_curve in frc_curves:
                 try:
-                    frc_res, _, _ = frcf.frc_res(xs_nm_freq, res_curve, img_size, threshold=curve_task.threshold)
+                    frc_res, _, _ = frcf.frc_res(xs_len_freq, res_curve, img_size, threshold=curve_task.threshold)
                     frc_res_list.append(frc_res)
                 except NoIntersectionException:
                     pass
@@ -248,14 +261,15 @@ def measure_curve(measure: FRCMeasurement, override_n: int = 0) -> FRCMeasuremen
 
         except NoIntersectionException as e:
             print(e)
+
         avg_desc = f"{curve_task.avg_n} curves averaged." if curve_task.avg_n > 1 else ""
-        desc = "Resolution ({} threshold): {:.3g} {}nm. {} {}".format(curve_task.threshold, frc_res, sd_str,
-                                                                      smooth_desc,
-                                                                      avg_desc)
+        desc = "Resolution ({} threshold) for {}: {:.3g} {}{}. {}{}".format(curve_task.threshold, curve_key, frc_res,
+                                                                            sd_str, measure.settings.len_unit,
+                                                                            smooth_desc, avg_desc)
 
         # Create curve object
-        curve = Curve(f"{measure.group_name}-{measure.index}-{curve_i}", xs_nm_freq, frc_curve, frc_res,
-                      f"{measure.group_name} measurement {measure.index}", label, desc,
+        curve = Curve(curve_key, xs_len_freq, frc_curve, frc_res,
+                      f"{curve_key}", label, desc,
                       res_sd, res_y, thres_curve, curve_task.threshold, measure)
         curves.append(curve)
     measure.curves = curves
